@@ -170,7 +170,7 @@ impl fmt::Display for AllowedUrlError {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         use AllowedUrlError::*;
         match self {
-            HrefParseError(e) => write!(f, "URL parse error: {e}"),
+            HrefParseError(e) => write!(f, "URL parse error: {}", e),
             BaseRequired => write!(f, "base required"),
             DifferentUriSchemes => write!(f, "different URI schemes"),
             DisallowedScheme => write!(f, "disallowed scheme"),
@@ -378,13 +378,13 @@ mod tests {
 
     #[test]
     fn disallows_queries() {
-        assert!(matches!(
-            AllowedUrl::from_href(
-                ".?../../../../../../../../../../etc/passwd",
-                Some(url_from_test_fixtures("../tests/fixtures/loading/bar.svg")).as_ref(),
-            ),
-            Err(AllowedUrlError::NoQueriesAllowed)
-        ));
+        match AllowedUrl::from_href(
+            ".?../../../../../../../../../../etc/passwd",
+            Some(url_from_test_fixtures("../tests/fixtures/loading/bar.svg")).as_ref(),
+        ) {
+            Err(AllowedUrlError::NoQueriesAllowed) => (),
+            _ => panic!(),
+        }
     }
 
     #[test]
@@ -428,14 +428,15 @@ mod tests {
         println!("cwd: {:?}", std::env::current_dir());
         let base_url = url_from_test_fixtures("../tests/fixtures/loading/bar.svg");
 
-        assert!(matches!(
-            AllowedUrl::from_href(".", Some(&base_url)),
-            Err(AllowedUrlError::NotSiblingOrChildOfBaseFile)
-        ));
-        assert!(matches!(
-            AllowedUrl::from_href(".#../../../../../../../../../../etc/passwd", Some(&base_url)),
-            Err(AllowedUrlError::NoFragmentIdentifierAllowed)
-        ));
+        match AllowedUrl::from_href(".", Some(&base_url)) {
+            Err(AllowedUrlError::NotSiblingOrChildOfBaseFile) => (),
+            _ => panic!(),
+        }
+
+        match AllowedUrl::from_href(".#../../../../../../../../../../etc/passwd", Some(&base_url)) {
+            Err(AllowedUrlError::NoFragmentIdentifierAllowed) => (),
+            _ => panic!(),
+        }
     }
 
     #[test]
@@ -444,10 +445,10 @@ mod tests {
         // This is because they should have been stripped before calling that function,
         // by the Iri machinery.
 
-        assert!(matches!(
-            AllowedUrl::from_href("bar.svg#fragment", Some(Url::parse("https://example.com/foo.svg").unwrap()).as_ref()),
-            Err(AllowedUrlError::NoFragmentIdentifierAllowed)
-        ));
+        match AllowedUrl::from_href("bar.svg#fragment", Some(Url::parse("https://example.com/foo.svg").unwrap()).as_ref()) {
+            Err(AllowedUrlError::NoFragmentIdentifierAllowed) => (),
+            _ => panic!(),
+        }
      }
 
     #[test]
